@@ -1,4 +1,4 @@
-import sys, argparse
+import sys, argparse, argcomplete
 
 # option decorator
 def option(*args, **kwds):
@@ -25,9 +25,8 @@ def option_group(*options):
 
 class MetaCommander(type):
     def __new__(cls, classname, bases, classdict):
-        classdict = dict(classdict)
         subcmds = {}
-        for name, func in classdict.items():
+        for name, func in list(classdict.items()):
             if name.startswith('do_'):
                 name = name[3:]
                 subcmd = {
@@ -43,12 +42,12 @@ class MetaCommander(type):
 
 
 
-class Commander(object):
+class Commander(object, metaclass=MetaCommander):
     name = 'app'
     description = 'a description'
     version = '0.0'
     epilog = ''
-    default_args = ['--help']
+    default_args = []
     
     def parse_args(self):
         parser = argparse.ArgumentParser(
@@ -79,7 +78,10 @@ class Commander(object):
             for args, kwds in subcmd['options']:
                 subparser.add_argument(*args, **kwds)
             subparser.set_defaults(func=subcmd['func'])
-
+        
+        # Call argcomplete
+        argcomplete.autocomplete(self.parser)
+        
         if len(sys.argv) <= 1:
             options = self.parser.parse_args(self.default_args)
         else:
@@ -87,5 +89,3 @@ class Commander(object):
         
         self.options = options
         options.func(self, options)
-
-Commander = MetaCommander('Commander', (object,), Commander.__dict__)
